/*
 ~  Copyright (c) 2008, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 ~
 ~  Licensed under the Apache License, Version 2.0 (the "License");
 ~  you may not use this file except in compliance with the License.
 ~  You may obtain a copy of the License at
 ~
 ~        http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~  Unless required by applicable law or agreed to in writing, software
 ~  distributed under the License is distributed on an "AS IS" BASIS,
 ~  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~  See the License for the specific language governing permissions and
 ~  limitations under the License.
 */

// This contains some utility functions shared by two or more endpoints

// check if a given field is empty
function isEmptyField(id) {
    var elementId = document.getElementById(id);
    if (elementId != null && elementId != undefined) {
        if (elementId.value == "" || elementId.value == null || elementId.value == undefined) {
            return true;
        }
    }
    return false;
}

// check the url is a valid one
function isValidURL(url) {
    if (url.search(/['",]/) != -1) { // we have , ' " in the URL
        return false;
    }
    var regx = RegExp("((fix|jms|http|https|ftp|file):/.*)|file:.*|mailto:.*");
    if (!(url.match(regx))) {
        return false;
    }
    return true;
}

function getElementValue(id) {
    var elementValue = document.getElementById(id);
    if (elementValue != null && elementValue != undefined) {
        elementValue = elementValue.value;
    }
    if (elementValue != null && elementValue != undefined) {
        return elementValue;
    }
    return null;
}

// set the action for time out
function activateDurationField(selectNode) {
    var selectOption = selectNode.options[selectNode.selectedIndex].value;
    var actionDuration = document.getElementById('actionDuration');
    if (selectOption != null && selectOption != undefined) {
        if (selectOption == 'neverTimeout') {
            if (actionDuration != null && actionDuration != undefined) {
                actionDuration.disabled = 'disabled';
                actionDuration.value = 0;
            }
        } else {
            if (actionDuration != null && actionDuration != undefined) {
                actionDuration.disabled = '';
            }
        }
    }
}

// a trim function- remove spaces
function trim(stringToTrim) {
    return stringToTrim.replace(/^\s+|\s+$/g, "");
}
function ltrim(stringToTrim) {
    return stringToTrim.replace(/^\s+/, "");
}
function rtrim(stringToTrim) {
    return stringToTrim.replace(/\s+$/, "");
}

function cacelEndpointData(annonOriginator) {
    if (annonOriginator != 'null') {
        document.location.href = annonOriginator + '?cancelled=true';
    } else if (annonOriginator == 'null') {
        document.location.href = 'index.jsp';
    }
}

function XMLToString(xmlData) {
    var xmlDoc;
    if (window.ActiveXObject) {
        //for IE
        xmlDoc = new ActiveXObject("Microsoft.XMLDOM");
        xmlDoc.async = "false";
        xmlDoc.loadXML(xmlData);
        return xmlDoc.xml;
    } else if (document.implementation && document.implementation.createDocument) {
        //for Mozila
        parser = new DOMParser();
        xmlDoc = parser.parseFromString(xmlData, "text/xml");
        return (new XMLSerializer()).serializeToString(xmlDoc);
    }
    return null;
}

function xmlToString(xmlObj) {
    if (navigator.appName == "Netscape")
    {
        return (new XMLSerializer()).serializeToString(xmlObj);
    }
    if (navigator.appName == "Microsoft Internet Explorer")
    {
        return xmlObj.xml;
    }
    return null;
}

function getText(ele) {
    var strings = [];
    getStrings(ele, strings);
    return strings.join("");
}

function getStrings(n, strings) {
    if (n.nodeType == 3 /* Node.TEXT_NODE */)
        strings.push(n.data);
    else if (n.nodeType == 1 /* Node.ELEMENT_NODE */) {
        for (var m = n.firstChild; m != null; m = m.nextSibling) {
            getStrings(m, strings);
        }
    }
}

// validate an Addresss or WSDL data entered
function isValidAddressORWSDLEndpoint(isAnonymous, endpointType) {

    if (isAnonymous == 'false') {
        if (isEmptyField('endpointName')) {
            CARBON.showWarningDialog(jsi18n['name.field.cannot.be.empty']);
            return false;
        }
    }

    if (endpointType == 'address') {

        if (isEmptyField('address')) {
            CARBON.showWarningDialog(jsi18n['address.field.cannot.be.empty']);
            return false;
        }

        // check for a valid URL
        var endpointURI = getElementValue('address');
        if (endpointURI != null) {
            if (!isValidURL(endpointURI)) {
                CARBON.showWarningDialog(jsi18n['invalid.url.provided']);
                return false;
            }
        }

    } else if (endpointType == 'wsdl') {
        var inlineWSDL = document.getElementById('inlineWSDL');
        if (inlineWSDL != null && inlineWSDL != undefined) {
            if (inlineWSDL.checked) {
                // not empty
                var inlineWSDLVal = document.getElementById('inlineWSDLVal').value;
                if (inlineWSDLVal != null && inlineWSDLVal != undefined) {
                    // is empty ?
                    if (trim(inlineWSDLVal) == '' || ltrim(inlineWSDLVal) == ''
                            || trim(inlineWSDLVal) == '') {
                        CARBON.showWarningDialog(jsi18n['inline.wsdl.cannot.be.empty']);
                        return false;
                    }
                    // is a valid xml doc ?
                    // the WSDL should not contain the xml delecraion
                    if (!isValidWSDL(inlineWSDLVal)) {
                        CARBON.showWarningDialog(jsi18n['invalid.wsdl.definition.xml.parse.error']);
                        return false;
                    }
                }
            }
        }
        var uri = document.getElementById('uriWSDL');
        if (uri != null && uri != undefined) {
            if (uri.checked) {
                if (isEmptyField('uriWSDLVal')) {
                    CARBON.showWarningDialog(jsi18n['wsdl.uri.field.cannot.be.empty']);
                    return false;
                }

            }
        }

        if (isEmptyField('wsdlendpointService')) {
            CARBON.showWarningDialog(jsi18n['service.field.cannot.be.empty']);
            return false;
        }

        if (isEmptyField('wsdlendpointPort')) {
            CARBON.showWarningDialog(jsi18n['port.field.cannot.be.empty']);
            return false;
        }
    }

    /*var errorVal = getElementValue('suspendErrorCode');
    if (errorVal != null) {
        if (isNaN(errorVal)) {
            CARBON.showWarningDialog(jsi18n['please.enter.a.numeric.value.to.the.error.code']);
            return false;
        }
    } */

    var durationVal = getElementValue('suspendDuration');
    if (durationVal != null) {
        if (isNaN(durationVal)) {
            CARBON.showWarningDialog(jsi18n['please.enter.a.numeric.value.to.the.suspend.duration.seconds.field']);
            return false;
        }
    }

    var maxDurationVal = getElementValue('suspendMaxDuration');
    if (maxDurationVal != null) {
        if (isNaN(maxDurationVal)) {
            CARBON.showWarningDialog(jsi18n['please.enter.a.valid.number.to.the.max.duration.seconds.field']);
            return false;
        }
    }

    var factorVal = getElementValue('factor');
    if (factorVal != null) {
        if (isNaN(factorVal)) {
            CARBON.showWarningDialog(jsi18n['please.enter.a.valid.number.to.the.factor.field']);
            return false;
        }
    }

    /*var retryErroCode = getElementValue('retryErroCode');
    if (retryErroCode != null) {
        if (isNaN(retryErroCode)) {
            CARBON.showWarningDialog(jsi18n['please.enter.a.numeric.value.to.the.error.code']);
            return false;
        }
    } */

    var retryTimeoutVal = getElementValue('retryTimeOut');
    if (retryTimeoutVal != null) {
        if (isNaN(retryTimeoutVal)) {
            CARBON.showWarningDialog(jsi18n['please.enter.a.valid.number.to.the.retry.field']);
            return false;
        }
    }

    var retryDelay = getElementValue('retryDelay');
    if (retryDelay != null) {
        if (isNaN(retryDelay)) {
            CARBON.showWarningDialog(jsi18n['please.enter.a.valid.number.to.the.retrydelay.field']);
            return false;
        }
    }

    return true;
}

function convertToValidXMlString(originalStr) {
    //Replace all the correct code with invalid code
    var convertedStr = relpaceString(originalStr, "&amp;", "&");
    convertedStr = relpaceString(convertedStr, "&lt;", "<");
    convertedStr = relpaceString(convertedStr, "&gt;", ">");
    convertedStr = relpaceString(convertedStr, "&quot;", '"');
    //    convertedStr = relpaceString(convertedStr, "&#39;", "'");

    //Replace all the invalid code with correct code
    convertedStr = relpaceString(convertedStr, "&", "&amp;");
    convertedStr = relpaceString(convertedStr, "<", "&lt;");
    convertedStr = relpaceString(convertedStr, ">", "&gt;");
    convertedStr = relpaceString(convertedStr, '"', "&quot;");
    //    convertedStr = relpaceString(convertedStr, "'", "&#39;");
    return convertedStr;

}

function relpaceString(originalStr, originalword, relaceword) {
    if (originalStr == undefined || originalStr == null) {
        return null;
    }
   return originalStr.replace(originalword,relaceword);
}

